%define _libdir64 %{_prefix}/lib64

Name:           dar
Version:        2.3.8
Release:        1
Summary:        Software for making/restoring incremental CD/DVD backups
Group:          Applications/Archiving
License:        GPLv2+
URL:            http://dar.linux.free.fr/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Patch0:         %{name}-%{version}-aix.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:  gcc >= 4.2.3-2
BuildRequires:  gcc-c++ >= 4.2.3-2
BuildRequires:  libstdc++-devel >= 4.2.3-2

BuildRequires:  bzip2 >= 1.0.2-4
BuildRequires:  gettext
BuildRequires:  openssl-devel >= 0.9.8
BuildRequires:  zlib-devel >= 1.2.3-3

Requires:       libdar = %{version}-%{release}
Requires:       gettext
Requires:       libgcc >= 4.2.3-2
Requires:       libstdc++ >= 4.2.3-2

%description
DAR is a command line tool to backup a directory tree and files. DAR is
able to make differential backups, split them over a set of disks or files
of a given size, use compression, filter files or subtrees to be saved or
not saved, directly access and restore given files. DAR is also able
to handle extented attributes, and can make remote backups through an
ssh session for example. Finally, DAR handles save and restore of hard
and symbolic links.


%package -n libdar
Group:      System Environment/Libraries
Summary:    Library providing support for the DAR API
Requires:   bzip2 >= 1.0.2-4
Requires:   libgcc >= 4.2.3-2
Requires:   libstdc++ >= 4.2.3-2
Requires:   openssl >= 0.9.8
Requires:   zlib >= 1.2.3-3

%description -n libdar
Common library code for DAR.


%package -n libdar-devel
Group:      Development/Libraries
Summary:    Development files for libdar
Requires:   libdar = %{version}-%{release}

%description -n libdar-devel
This package contains the header files and libraries for developing
programs that use the DAR API (libdar).


%prep
%setup -q
%patch0
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CFLAGS="-DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O -I/opt/freeware/include"
export CXXFLAGS="${CFLAGS}"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export CC="gcc -maix64 -D_LARGE_FILES"
export CXX="g++ -maix64 -D_LARGE_FILES"
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static \
    --disable-build-html
make %{?_smp_mflags} AM_LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -lintl"

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export CC="gcc -maix32 -D_LARGE_FILES"
export CXX="g++ -maix32 -D_LARGE_FILES"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static \
    --disable-build-html
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so*

# delete the sample files that we can't seem to disable
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}

# remove the doc makefiles so they don't get installed along with the other files.
rm -f doc/Makefile*
rm -f doc/*/Makefile*

# rename the documentation directory so it makes more sense after installation.
mv doc html

# sample scripts should not be executable
chmod 0644 html/samples/*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/html/ 32bit/AUTHORS 32bit/ChangeLog 32bit/COPYING 32bit/NEWS
%doc 32bit/README 32bit/THANKS 32bit/TODO
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/locale/*/*/*
/usr/bin/*


%files -n libdar
%defattr(-,root,system,-)
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files -n libdar-devel
%defattr(-,root,system,-)
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Mon Sep 17 2012 Michael Perzl <michael@perzl.org> - 2.3.8-1
- first version for AIX V5.1 and higher
